# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.3.5] - 2019-05-30
### Changed
- Fix #85 Add Nice Status URL by [@dmlb2000](https://github.com/dmlb2000)

## [0.3.4] - 2019-05-17
### Added
- Ingest services to consume data bundles
- Backend services to send files to archiveinterface
- Backend services to send metadata to metadata service
- Validation of data before it hits archiveinterface
- Status tracking endpoint for state of ingest task
- ReadtheDocs supported Sphinx docs

### Changed
